==> dl.php?src=linea21_1_3.zip: linea21/templates/admin/default/header.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage admin
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
echo '<?xml version="1.0" encoding="' . CHARSET . '"  xml:lang="' .LANGUAGE. '" ?>'. END_LINE;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo LANGUAGE; ?>">
<head>
<title><?php echo _t('header','title');?></title>
<meta http-equiv="content-language" content="<?php echo LANGUAGE;?>" />
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET;?>" />
<link rel="shortcut icon" href="<?php echo THEME_ADMIN_PATH; ?>images/favicon.ico" />
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_common.css" />
<style type="text/css" media="all">
<?php
if (basename($_SERVER['SCRIPT_NAME']) != 'search.php') {
    echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css);';
} else {
	echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_search.css);';
} 

?>
</style>
<!--[if lte IE 7]>
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_ie.css" />
<![endif]-->
<script type="text/javascript">
var SITE_ROOT_URL="<?php echo SITE_ROOT_URL; ?>";
var lang ="<?php echo LANGUAGE; ?>";
</script>
<script type="text/javascript" src="../lib/js/jquery.min.js"></script>
<?php IncludeTextResizerJs(); ?>
<?php IncludeLightboxJs(); ?>
<?php IncludedatePickerJs(); ?>
<?php IncludeMultiSelectJs(); ?>
<?php IncludeRichTextEditor(); ?>
<?php IncludeTextCornerJs(); ?>
<?php IncludeJsTreeJs(); ?>
<?php IncludeTimeline(); ?>
<script type="text/javascript" src="../lib/js/functions_admin.js"></script>
<script type="text/javascript" src="../lib/js/menu.config.js"></script>
</head>
<body>
<div id="container" style="background-image: url(<?php echo THEME_ADMIN_PATH; ?>images/bgcontainer.png);">
<!-- barre haute -->
<div id="tools_right">

<div id="deconnexion">
	<a href="logout.php"><?php echo _t('header','deconnexion');
?></a>
</div>
<br style="clear:both;"/>
<div id="bienvenue"><?php echo _t('header','welcome');
?> <span><?php echo GetSessionElement('login');
?></span></div>
<br style="clear:both;"/>

	<div id="containersearch">
	<form method="post" action="search.php">
		<input type="text" class="searchincome" name="search" id="searchincome"  accesskey="s" value="<?php echo _t('menu_alt','search_here'); ?>" onclick="if (this.defaultValue==this.value) this.value=''" onblur="if (this.value=='') this.value=this.defaultValue" />
		<input type="submit" id="gosearch"   name="valid" value="" />
		</form>
	</div>

</div>
<!--end barre haute -->

==> dl.php?src=linea21_1_4.zip: linea21/templates/admin/default/header.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage admin
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
echo '<?xml version="1.0" encoding="' . CHARSET . '"  xml:lang="' .U_L. '" ?>'. END_LINE;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo U_L; ?>">
<head>
<title><?php echo _t('header','title');?></title>
<meta http-equiv="content-language" content="<?php echo U_L;?>" />
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET;?>" />
<link rel="shortcut icon" href="<?php echo THEME_ADMIN_PATH; ?>images/favicon.ico" />
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_common.css" />
<style type="text/css" media="all">
<?php
if (basename($_SERVER['SCRIPT_NAME']) != 'search.php') {
  if(file_exists(THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css')) {
    echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_' . $rub . '.css);';
  }
} else {
	echo '@import url(' .THEME_ADMIN_PATH. 'css/admin_search.css);';
}
?>
</style>
<!--[if lte IE 7]>
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_ie.css" />
<![endif]-->
<script type="text/javascript">
var SITE_ROOT_URL= "<?php echo SITE_ROOT_URL; ?>";
var lang = "<?php echo U_L; ?>";
</script>
<script type="text/javascript" src="../lib/js/jquery.min.js"></script>
<?php IncludePHPDebug(); ?>
<?php IncludeTextResizerJs(); ?>
<?php IncludeLightboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']")); ?>
<?php IncludedatePickerJs(); ?>
<?php IncludeMultiSelectJs(); ?>
<?php IncludeTextCornerJs(); ?>
<?php IncludeTreeJs(); ?>
<?php IncludeTooltipJs('abbr[title]'); ?>
<?php IncludeTextBoxListJs(); ?>
<?php IncludeTimeline(); ?>
<?php AddDynamicHeader(); ?>
<script type="text/javascript" src="../lib/js/functions_admin.js"></script>
<script type="text/javascript" src="../lib/js/menu.config.js"></script>
</head>
<body>
<div id="container" style="background-image: url(<?php echo THEME_ADMIN_PATH; ?>images/bgcontainer.png);">
<!-- barre haute -->
<div id="tools_right">

<div id="deconnexion">
	<a href="logout.php"><?php echo _t('header','deconnexion');
?></a>
</div>
<br style="clear:both;"/>
<div id="bienvenue"><?php echo _t('header','welcome');
?> <span><?php echo GetSessionElement('login');
?></span></div>
<br style="clear:both;"/>

	<div id="containersearch">
	<form method="post" action="search.php">
		<input type="text" class="searchincome" name="search" id="searchincome"  accesskey="s" value="<?php echo _t('menu_alt','search_here'); ?>" onclick="if (this.defaultValue==this.value) this.value=''" onblur="if (this.value=='') this.value=this.defaultValue" />
		<input type="submit" id="gosearch"   name="valid" value="" />
		</form>
	</div>

</div>
<!--end barre haute -->
